@@ -1,9 +1,6 @@
 /*PGR-GNU*****************************************************************
 File: e_report.h
 
-Copyright (c) 2016 pgRouting developers
-Mail: project@pgrouting.org
-
 Function's developer:
 Copyright (c) 2016 Celia Virginia Vergara Castillo
 Mail: vicky_vergara@hotmail.com
@@ -56,7 +53,6 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  */
 
-///@{
 /*! @brief notice & error
  *
  *  ~~~~{.c}
@@ -70,76 +66,11 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 void
 pgr_global_report(
-        char* log_msg,
-        char* notice_msg,
-        char* error_msg);
-
-/*! @brief notice with no hint
- *
- *  ~~~~{.c}
- *  pgr_notice(&log_msg, &notice_msg);
- *
- *  precondition: before calling ereport
- *      assert(!log_msg);
- *      assert(!notice_msg);
- *  ~~~~
- */
-void
-pgr_notice(
-        char* notice_msg);
-
-/*! @brief notice with hint
- *
- *  ~~~~{.c}
- *  pgr_notice(&log_msg, &notice_msg);
- *
- *  precondition: before calling ereport
- *      assert(!log_msg);
- *      assert(!notice_msg);
- *  ~~~~
- */
-void
-pgr_notice2(
-        char* log_msg,
-        char* notice_msg);
-
-/*! @brief error with no hint
- *
- *
- *  ~~~~{.c}
- *  if (err_msg) {
- *      pfree(<data>);
- *  }
- *  pgr_error(&error_msg);
- *
- *  precondition: before calling ereport
- *      assert(!*error_msg);
- *  ~~~~
- */
-void
-pgr_error(char* error_msg);
+        char** log_msg,
+        char** notice_msg,
+        char** error_msg);
 
 /* @brief throws postgres error when first string is not null */
-void throw_error(char*, char*);
-
-
-/*! @brief error with hint
- *
- *  ~~~~{.c}
- *  if (err_msg) {
- *      pfree(<data>);
- *  }
- *  pgr_error(&log_msg, &error_msg);
- *
- *  precondition: before calling ereport
- *      assert(!*log_msg);
- *      assert(!*error_msg);
- *  ~~~~
- */
-void
-pgr_error2(
-        char* log_msg,
-        char* error_msg);
-///@}
+void pgr_throw_error(char*, char*);
 
 #endif  // INCLUDE_C_COMMON_E_REPORT_H_
