@@ -34,81 +34,111 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <sstream>
 #include <deque>
 #include <vector>
+#include <string>
 
-#include "yen/pgr_ksp.hpp"
+#include "yen/ksp.hpp"
 
-#include "cpp_common/combinations.h"
-#include "cpp_common/pgr_alloc.hpp"
-#include "cpp_common/pgr_assert.h"
-
-#include "cpp_common/pgr_base_graph.hpp"
+#include "cpp_common/combinations.hpp"
+#include "cpp_common/pgdata_getters.hpp"
+#include "cpp_common/alloc.hpp"
+#include "cpp_common/assert.hpp"
 
 #include "c_types/ii_t_rt.h"
 
-void  pgr_do_ksp(
-        Edge_t *data_edges, size_t total_edges,
-        II_t_rt *combinationsArr, size_t total_combinations,
-        int64_t*  start_vids, size_t size_start_vids,
-        int64_t * end_vids, size_t size_end_vids,
+void pgr_do_ksp(
+        char* edges_sql,
+        char* combinations_sql,
+        ArrayType* starts,
+        ArrayType* ends,
+
+        int64_t *start_vid,
+        int64_t *end_vid,
+
         size_t k,
         bool directed,
         bool heap_paths,
         Path_rt **return_tuples,
         size_t *return_count,
-        char ** log_msg,
-        char ** notice_msg,
-        char ** err_msg) {
+        char **log_msg,
+        char **notice_msg,
+        char **err_msg) {
     using pgrouting::Path;
     using pgrouting::pgr_alloc;
     using pgrouting::pgr_msg;
     using pgrouting::pgr_free;
+    using pgrouting::utilities::get_combinations;
     using pgrouting::yen::Pgr_ksp;
 
     std::ostringstream err;
     std::ostringstream log;
     std::ostringstream notice;
+    char *hint = nullptr;
+
     try {
         pgassert(!(*log_msg));
         pgassert(!(*notice_msg));
         pgassert(!(*err_msg));
         pgassert(!(*return_tuples));
         pgassert(*return_count == 0);
-        pgassert(total_edges != 0);
 
-        auto combinations = total_combinations?
-            pgrouting::utilities::get_combinations(combinationsArr, total_combinations)
-            : pgrouting::utilities::get_combinations(start_vids, size_start_vids, end_vids, size_end_vids);
 
-        graphType gType = directed? DIRECTED: UNDIRECTED;
 
-        std::deque< Path > paths;
+        hint = combinations_sql;
+        auto combinations = get_combinations(combinations_sql, starts, ends, true);
+        hint = nullptr;
 
-        if (directed) {
-            pgrouting::DirectedGraph digraph(gType);
-            digraph.insert_edges(data_edges, total_edges);
-            paths = pgrouting::algorithms::Yen(digraph, combinations, k, heap_paths);
-        } else {
-            pgrouting::UndirectedGraph undigraph(gType);
-            undigraph.insert_edges(data_edges, total_edges);
-            paths = pgrouting::algorithms::Yen(undigraph, combinations, k, heap_paths);
+        if (start_vid && end_vid) {
+            combinations[*start_vid].insert(*end_vid);
         }
 
+        if (combinations.empty() && combinations_sql) {
+            *notice_msg = pgr_msg("No (source, target) pairs found");
+            *log_msg = pgr_msg(combinations_sql);
+            return;
+        }
 
-        auto count(count_tuples(paths));
+        hint = edges_sql;
+        auto edges = pgrouting::pgget::get_edges(std::string(edges_sql), true, false);
 
-        if (!(count == 0)) {
-            *return_tuples = NULL;
-            *return_tuples = pgr_alloc(count, (*return_tuples));
+        if (edges.empty()) {
+            *notice_msg = pgr_msg("No edges found");
+            *log_msg = hint? pgr_msg(hint) : pgr_msg(log.str().c_str());
+            return;
+        }
+        hint = nullptr;
 
-            size_t sequence = 0;
-            for (const auto &path : paths) {
-                if (path.size() > 0)
-                    path.get_pg_nksp_path(return_tuples, sequence);
-            }
+        std::deque<Path>paths;
+
+        if (directed) {
+            pgrouting::DirectedGraph graph;
+            graph.insert_edges(edges);
+            paths = pgrouting::algorithms::Yen(graph, combinations, k, heap_paths);
+        } else {
+            pgrouting::UndirectedGraph graph;
+            graph.insert_edges(edges);
+            paths = pgrouting::algorithms::Yen(graph, combinations, k, heap_paths);
+        }
+        combinations.clear();
+
+        auto count = count_tuples(paths);
+
+        if (count == 0) {
+            (*return_tuples) = NULL;
+            (*return_count) = 0;
+            notice << "No paths found";
+            *log_msg = pgr_msg(notice.str().c_str());
+            return;
+        }
+
+        (*return_tuples) = pgr_alloc(count, (*return_tuples));
+        (*return_count) = (collapse_paths(return_tuples, paths));
+
+        size_t sequence = 0;
+        for (const auto &path : paths) {
+            if (path.size() > 0) path.get_pg_nksp_path(return_tuples, sequence);
         }
         *return_count = count;
 
-        pgassert(*err_msg == NULL);
         *log_msg = log.str().empty()?
             *log_msg :
             pgr_msg(log.str().c_str());
@@ -121,6 +151,9 @@ void  pgr_do_ksp(
         err << except.what();
         *err_msg = pgr_msg(err.str().c_str());
         *log_msg = pgr_msg(log.str().c_str());
+    } catch (const std::string &ex) {
+        *err_msg = pgr_msg(ex.c_str());
+        *log_msg = hint? pgr_msg(hint) : pgr_msg(log.str().c_str());
     } catch (std::exception &except) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
