@@ -1,5 +1,5 @@
 /*PGR-GNU*****************************************************************
-File: mst_common.c
+File: mst_common.cpp
 
 Copyright (c) 2015 pgRouting developers
 Mail: project@pgrouting.org
@@ -30,8 +30,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <string>
 #include <sstream>
 
-#include "cpp_common/pgr_assert.h"
-#include "cpp_common/pgr_alloc.hpp"
+#include "cpp_common/assert.hpp"
+#include "cpp_common/alloc.hpp"
 
 int
 get_order(char * fn_suffix, char ** err_msg) {
