@@ -38,17 +38,19 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
 #include <set>
 #include <map>
 #include <cassert>
+#include <string>
 
-#include "trsp/pgr_trspHandler.h"
+#include "trsp/trspHandler.hpp"
+#include "cpp_common/pgdata_getters.hpp"
 #include "cpp_common/rule.hpp"
-#include "cpp_common/pgr_assert.h"
-#include "cpp_common/pgr_alloc.hpp"
-#include "cpp_common/combinations.h"
-#include "c_types/restriction_t.h"
+#include "cpp_common/assert.hpp"
+#include "cpp_common/alloc.hpp"
+#include "cpp_common/combinations.hpp"
+#include "cpp_common/restriction_t.hpp"
 #include "c_types/ii_t_rt.h"
-#include "dijkstra/dijkstra.hpp"
-#include "withPoints/pgr_withPoints.hpp"
+#include "withPoints/withPoints.hpp"
 
+#include "dijkstra/dijkstra.hpp"
 
 namespace {
 
@@ -93,13 +95,12 @@ pgr_dijkstra(
 }  // namespace
 
 void
-do_trsp(
-        Edge_t *edges, size_t total_edges,
-        Restriction_t *restrictions, size_t restrictions_size,
-
-        II_t_rt *combinations_arr, size_t total_combinations,
-        int64_t *starts_arr, size_t size_starts_arr,
-        int64_t *ends_arr, size_t size_ends_arr,
+pgr_do_trsp(
+        char *edges_sql,
+        char *restrictions_sql,
+        char *combinations_sql,
+        ArrayType *starts,
+        ArrayType *ends,
 
         bool directed,
 
@@ -112,37 +113,53 @@ do_trsp(
     using pgrouting::pgr_alloc;
     using pgrouting::pgr_msg;
     using pgrouting::pgr_free;
+    using pgrouting::utilities::get_combinations;
 
     std::ostringstream log;
     std::ostringstream notice;
     std::ostringstream err;
+    char *hint = nullptr;
+
     try {
-        pgassert(edges);
         pgassert(!(*log_msg));
         pgassert(!(*notice_msg));
         pgassert(!(*err_msg));
         pgassert(!(*return_tuples));
         pgassert(*return_count == 0);
 
-        graphType gType = directed? DIRECTED: UNDIRECTED;
+        hint = combinations_sql;
+        auto combinations = get_combinations(combinations_sql, starts, ends, true);
+        hint = nullptr;
+
+        if (combinations.empty() && combinations_sql) {
+            *notice_msg = pgr_msg("No (source, target) pairs found");
+            *log_msg = pgr_msg(combinations_sql);
+            return;
+        }
+
+        hint = edges_sql;
+        auto edges = pgrouting::pgget::get_edges(std::string(edges_sql), true, false);
+        hint = nullptr;
+
+        if (edges.empty()) {
+            *notice_msg = pgr_msg("No edges found");
+            *log_msg = pgr_msg(edges_sql);
+            return;
+        }
 
-        auto vertices(pgrouting::extract_vertices(edges, total_edges));
 
-        auto combinations = total_combinations?
-            pgrouting::utilities::get_combinations(combinations_arr, total_combinations)
-            : pgrouting::utilities::get_combinations(starts_arr, size_starts_arr, ends_arr, size_ends_arr);
 
         std::deque<Path> paths;
         if (directed) {
-            pgrouting::DirectedGraph digraph(vertices, gType);
-            digraph.insert_edges(edges, total_edges);
+            pgrouting::DirectedGraph digraph;
+            digraph.insert_edges(edges);
 
             paths = pgr_dijkstra(
                     digraph,
                     combinations);
         } else {
-            pgrouting::UndirectedGraph undigraph(vertices, gType);
-            undigraph.insert_edges(edges, total_edges);
+            pgrouting::UndirectedGraph undigraph;
+            undigraph.insert_edges(edges);
 
             paths = pgr_dijkstra(
                     undigraph,
@@ -159,7 +176,7 @@ do_trsp(
             return;
         }
 
-        if (restrictions_size == 0) {
+        if (!restrictions_sql) {
             (*return_tuples) = pgr_alloc(count, (*return_tuples));
             (*return_count) = (collapse_paths(return_tuples, paths));
             return;
@@ -168,18 +185,25 @@ do_trsp(
         /*
          * When there are turn restrictions
          */
-        std::vector<pgrouting::trsp::Rule> ruleList;
-        for (size_t i = 0; i < restrictions_size; ++i) {
-            if (restrictions[i].via_size == 0) continue;
-            ruleList.push_back(pgrouting::trsp::Rule(*(restrictions + i)));
+        hint = restrictions_sql;
+        auto restrictions = pgrouting::pgget::get_restrictions(std::string(restrictions_sql));
+        if (restrictions.empty()) {
+            (*return_tuples) = pgr_alloc(count, (*return_tuples));
+            (*return_count) = (collapse_paths(return_tuples, paths));
+            return;
         }
 
+        std::vector<pgrouting::trsp::Rule> ruleList;
+        for (const auto &r : restrictions) {
+            if (r.via) ruleList.push_back(pgrouting::trsp::Rule(r));
+        }
+        hint = nullptr;
+
         auto new_combinations = pgrouting::utilities::get_combinations(paths, ruleList);
 
         if (!new_combinations.empty()) {
             pgrouting::trsp::Pgr_trspHandler gdef(
                     edges,
-                    total_edges,
                     directed,
                     ruleList);
             auto new_paths = gdef.process(new_combinations);
@@ -216,6 +240,9 @@ do_trsp(
         err << except.what();
         *err_msg = pgr_msg(err.str().c_str());
         *log_msg = pgr_msg(log.str().c_str());
+    } catch (const std::string &ex) {
+        *err_msg = pgr_msg(ex.c_str());
+        *log_msg = hint? pgr_msg(hint) : pgr_msg(log.str().c_str());
     } catch(...) {
         (*return_tuples) = pgr_free(*return_tuples);
         (*return_count) = 0;
