@@ -37,7 +37,8 @@ QUIET="-v"
 QUIET="-q"
 
 PGDATABASE="___pgr___test___"
-PGRVERSION="3.4.0 3.3.0 3.2.0 3.1.0 3.0.0"
+PGRVERSION="3.6.1 3.6.0 3.5.1 3.5.0 3.2.0 3.1.3 3.0.6"
+PGRVERSION="3.7.0"
 
 
 for v in ${PGRVERSION}
@@ -53,11 +54,18 @@ do
     psql "$PGFLAGS" -d "$PGDATABASE" -X -q --set client_min_messages=WARNING --set ON_ERROR_STOP=1 --pset pager=off \
         -c "CREATE EXTENSION IF NOT EXISTS pgtap; CREATE EXTENSION IF NOT EXISTS pgrouting WITH VERSION '${v}' CASCADE;"
 
+    echo "--------------------------"
+    echo " Installed version"
+    echo "--------------------------"
+    psql "${PGFLAGS}" -d "$PGDATABASE" -c "SELECT * FROM pgr_full_version();"
+    #psql "${PGFLAGS}" -d "$PGDATABASE" -c "SET client_min_messages TO DEBUG3; ALTER EXTENSION pgrouting UPDATE  TO '3.7.0';"
+    echo "--------------------------"
+    echo " update version"
+    echo "--------------------------"
     psql "${PGFLAGS}" -d "$PGDATABASE" -c "SELECT * FROM pgr_full_version();"
 
     psql "${PGFLAGS}" -d "$PGDATABASE" -X -q --set client_min_messages=WARNING --set ON_ERROR_STOP=1 --pset pager=off \
         -f sampledata.sql \
-        -f vrppdtw_data.sql \
         -f solomon_100_rc101.data.sql \
         -f innerQuery.sql \
         -f innerQuery_old.sql \
@@ -74,11 +82,13 @@ do
         -f types_check.sql \
         -f via_compare.sql \
         -f astar_pgtap_tests.sql \
+        -f compare_dijkstra.sql \
+        -f allpairs_tests.sql \
+        -f contraction_tapfuncs.sql\
         -f tsp_pgtap_tests.sql
 
 
     popd
     pg_prove "$QUIET" --normalize --directives --recurse "${PGFLAGS}"  -d "${PGDATABASE}" "pgtap/${DIR}"
-    #pg_prove "$QUIET" --normalize --directive --recurse "${PGFLAGS}"  -d "${PGDATABASE}" "../../pgtap/"
     #dropdb --if-exists "${PGFLAGS}" "${PGDATABASE}"
 done
