@@ -1,7 +1,7 @@
 #! /usr/bin/perl -w
 
 =pod
-File: aplgorithm testes
+File: doc_queries_generator.pl
 
 Copyright (c) 2013 pgRouting developers
 
@@ -48,13 +48,11 @@ use vars qw/*name *dir *prune/;
 *dir    = *File::Find::dir;
 *prune  = *File::Find::prune;
 
-my $POSGRESQL_MIN_VERSION = '9.2';
+my $POSGRESQL_MIN_VERSION = '12';
 my $DOCUMENTATION = 0;
-my $INTERNAL_TESTS = 0;
+my $DATA = 0;
 my $VERBOSE = 0;
-my $DRYRUN = 0;
-my $DEBUG = 0;
-my $DEBUG1 = 0;
+my $LEVEL = "NOTICE";
 my $FORCE = 0;
 
 my $DBNAME = "pgr_test__db__test";
@@ -64,35 +62,30 @@ my $DBPORT;
 
 sub Usage {
     die "Usage: doc_queries_generator.pl -pgver vpg -pgisver vpgis -psql /path/to/psql\n" .
-    "       -pgver vpg          - postgresql version\n" .
+    "       -alg 'dir'          - directory to select which algorithm subdirs to test\n" .
+    "       -pgver version      - postgresql version\n" .
     "       -pghost host        - postgresql host or socket directory to use\n" .
     "       -pgport port        - postgresql port to use\n" .
     "       -pguser username    - postgresql user role to use\n" .
-    "       -pgisver vpgis      - postgis version\n" .
-    "       -pgrver vpgr        - pgrouting version\n" .
+    "       -dbname name        - Database name defaults to $DBNAME\n" .
+    "       -pgrver version     - pgrouting version. (Not all compares will pass)\n" .
     "       -psql /path/to/psql - optional path to psql\n" .
-    "       -v                  - verbose messages for small debuging\n" .
-    "       -dbg                - use when CMAKE_BUILD_TYPE = DEBUG\n" .
-    "       -debug              - verbose messages for debuging(enter twice for more)\n" .
-    "       -debug1             - DEBUG1 messages (for timing reports)\n" .
-    "       -clean              - dropdb pgr_test__db__test\n" .
-    "       -ignorenotice       - ignore NOTICE statements when reporting failures\n" .
-    "       -alg 'dir'          - directory to select which algorithm subdirs to test\n" .
-    "       -documentation      - ONLY generate documentation examples\n" .
-    "       -force              - Force tests for unsupported versions >= 9.1 of postgreSQL \n" .
-    "       -h                  - help\n";
+    "       -data               - only install the sampledata.\n" .
+    "       -l(evel)  NOTICE    - client_min_messages value. Defaults to $LEVEL. other values can be WARNING, DEBUG3, etc\n" .
+    "       -c(lean)            - dropdb before running.\n" .
+    "       -doc(umentation)    - ONLY generate documentation examples. LEVEL is set to NOTICE\n" .
+    "       -v(erbose)          - verbose messages of the execution\n" .
+    "       -h(elp)             - help\n";
 }
 
 print "RUNNING: doc_queries_generator.pl " . join(" ", @ARGV) . "\n";
 
-my ($vpg, $postgis_ver, $vpgr, $psql);
+my ($vpg, $vpgr, $psql);
 my $alg = '';
 my @testpath = ("docqueries/");
 my @test_direcotry = ();
 my $clean;
-my $ignore;
 
-$postgis_ver = '';
 
 while (my $a = shift @ARGV) {
     if ( $a eq '-pgver') {
@@ -107,37 +100,32 @@ while (my $a = shift @ARGV) {
     elsif ($a eq '-pguser') {
         $DBUSER = shift @ARGV || Usage();
     }
-    elsif ($a eq '-pgisver') {
-        $postgis_ver = shift @ARGV || Usage();
-        $postgis_ver = " VERSION '$postgis_ver'";
-    }
     elsif ($a eq '-pgrver') {
         $vpgr = shift @ARGV || Usage();
     }
     elsif ($a eq '-alg') {
         $alg = shift @ARGV || Usage();
-        @testpath = ("docqueries/$alg");
+        @testpath = ("$alg");
+    }
+    elsif ($a eq '-dbname') {
+        $DBNAME = shift @ARGV || Usage();
     }
     elsif ($a eq '-psql') {
         $psql = shift @ARGV || Usage();
         die "'$psql' is not executable!\n"
         unless -x $psql;
     }
+    elsif ($a eq '-data') {
+        $DATA = 1;
+    }
     elsif ($a =~ /^-h/) {
         Usage();
     }
-    elsif ($a =~ /^-clean/) {
-        $clean = 1;;
+    elsif ($a =~ /^-c/i) {
+        $clean = 1;
     }
-    elsif ($a =~ /^-ignoren/i) {
-        $ignore = 1;;
-    }
-    elsif ($a =~ /^-debug1$/i) {
-        $DEBUG1 = 1 unless $DOCUMENTATION;
-    }
-    elsif ($a =~ /^-debug$/i) {
-        $DEBUG++;
-        $VERBOSE = 1;
+    elsif ($a =~ /^-l$/i) {
+        $LEVEL = $psql = shift @ARGV || Usage();
     }
     elsif ($a =~ /^-v/i) {
         $VERBOSE = 1;
@@ -147,10 +135,6 @@ while (my $a = shift @ARGV) {
     }
     elsif ($a =~ /^-doc(umentation)?/i) {
         $DOCUMENTATION = 1;
-        $DEBUG1 = 0; # disbale timing reports during documentation generation
-    }
-    elsif ($a =~ /^-dbg/i) {
-        $INTERNAL_TESTS = 1; #directory internalQueryTests is also tested
     }
     else {
         warn "Error: unknown option '$a'\n";
@@ -158,16 +142,18 @@ while (my $a = shift @ARGV) {
     }
 }
 
+# documentation gets NOTICE
+$LEVEL = "NOTICE" if $DOCUMENTATION;
+
 my $connopts = "";
 $connopts .= " -U $DBUSER" if defined $DBUSER;
 $connopts .= " -h $DBHOST" if defined $DBHOST;
 $connopts .= " -p $DBPORT" if defined $DBPORT;
-
-mysystem("dropdb $connopts $DBNAME") if $clean;
+print "connoptions '$connopts'\n" if $VERBOSE;
 
 %main::tests = ();
 my @cfgs = ();
-my %stats = (z_pass=>0, z_fail=>0, z_crash=>0);
+my %stats = (z_pass=>0, z_fail=>0, z_crash=>0,RunTimeTotal=>0);
 my $TMP = "/tmp/pgr-test-runner-$$";
 my $TMP2 = "/tmp/pgr-test-runner-$$-2";
 my $TMP3 = "/tmp/pgr-test-runner-$$-3";
@@ -186,15 +172,19 @@ if (length($psql)) {
 print "Operative system found: $OS\n";
 
 
+createTestDB($DBNAME);
+
+# Load the sample data & any other relevant data files
+mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql $DBNAME >> $TMP2 2>\&1 ");
+
+if ($DATA) {exit 0;};
+
 # Traverse desired filesystems
 File::Find::find({wanted => \&want_tests}, @testpath);
 
-die "Error: no test files found. Run this command from the top level pgRouting directory!\n" unless @cfgs;
-
-createTestDB($DBNAME);
+die "Error: no queries files found. Run this command from the top path of pgRouting repository!\n" unless @cfgs;
 
 $vpg = '' if ! $vpg;
-$postgis_ver = '' if ! $postgis_ver;
 
 # cfgs = SET of configuration file names
 # c  one file in cfgs
@@ -209,22 +199,14 @@ for my $c (@cfgs) {
 
     print Data::Dumper->Dump([\%main::tests],['test']) if $VERBOSE;
 
-    if ($main::tests{any} && !$DOCUMENTATION) {
-        push @{$stats{$c}}, run_test($c, $main::tests{any});
-        $found++;
-    }
-    elsif ($main::tests{any}{documentation} && $DOCUMENTATION) {
-        push @{$stats{$c}}, run_test($c, $main::tests{any});
-        $found++;
-    }
+    run_test($c, $main::tests{any});
+    $found++;
 
     if (! $found) {
-        $stats{$c} = "No tests were found for '$vpg-$postgis_ver'!";
+        $stats{$c} = "No files found for '$c'!";
     }
 }
 
-dropTestDB();
-
 print Data::Dumper->Dump([\%stats], ['stats']);
 
 unlink $TMP;
@@ -238,237 +220,197 @@ if ($stats{z_crash} > 0 || $stats{z_fail} > 0) {
 exit 0;      # signal we passed all the tests
 
 
-# c  one file in cfgs
+# file  one file in cfgs
 # t  contents of array that has keys comment, data and test
 sub run_test {
-    my $c = shift;
+    my $confFile = shift;
     my $t = shift;
-    my %res = ();
 
-    my $dir = dirname($c);
+    my $dir = dirname($confFile);
 
-    $res{comment} = $t->{comment} if $t->{comment};
-    #t->{data}  referencing the key data of the data files
-
-    my $singleDB = "____pgr___single_test___";
-    for my $testName (@{$t->{singleTest}}) {
-        createTestDB($singleDB);
-        mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql' $singleDB >> $TMP2 2>\&1 ");
-        for my $x (@{$t->{data}}) {
-            mysystem("$psql $connopts -A -t -q -f '$dir/$x' $singleDB >> $TMP2 2>\&1 ");
-        }
-        process_single_test($testName, $dir, $singleDB,\%res);
-        mysystem("dropdb $connopts $singleDB");
+    # There is data to load relative to the directory
+    for my $datafile (@{$t->{data}}) {
+        mysystem("$psql $connopts -A -t -q -f '$dir/$datafile' $DBNAME >> $TMP2 2>\&1 ");
     }
 
-    mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql $DBNAME >> $TMP2 2>\&1 ");
-    for my $x (@{$t->{data}}) {
-        mysystem("$psql $connopts -A -t -q -f '$dir/$x' $DBNAME >> $TMP2 2>\&1 ");
+    for my $file (@{$t->{files}}) {
+        process_single_test($file, $dir, $DBNAME);
     }
 
-    if ($INTERNAL_TESTS) {
-        for my $x (@{$t->{debugtests}}) {
-            process_single_test($x, $dir,, $DBNAME, \%res)
+    # Just in case but its not used
+    if ($OS =~/msys/ || $OS=~/MSW/ || $OS =~/cygwin/) {
+        for my $x (@{$t->{windows}}) {
+            process_single_test($x, $dir, $DBNAME)
+        }
+    } elsif ($OS=~/Mac/ ||  $OS=~/dar/) {
+        for my $x (@{$t->{macos}}) {
+            process_single_test($x, $dir, $DBNAME)
+        }
+    } else {
+        for my $x (@{$t->{linux}}) {
+            process_single_test($x, $dir, $DBNAME)
         }
     }
-    if ($DOCUMENTATION) {
-        for my $x (@{$t->{documentation}}) {
-            process_single_test($x, $dir,, $DBNAME, \%res);
-            my $cmd = q(perl -pi -e 's/[ \t]+$//');
-            $cmd .= " $dir/$x.result";
-            mysystem( $cmd );
-        }
-    }
-    else {
-        for my $x (@{$t->{tests}}) {
-            process_single_test($x, $dir,, $DBNAME, \%res)
-        }
-        if ($OS =~/msys/ || $OS=~/MSW/ || $OS =~/cygwin/) {
-            for my $x (@{$t->{windows}}) {
-                process_single_test($x, $dir,, $DBNAME, \%res)
-            }
-        } elsif ($OS=~/Mac/ ||  $OS=~/dar/) {
-            for my $x (@{$t->{macos}}) {
-                process_single_test($x, $dir,, $DBNAME, \%res)
-            }
-        } else {
-            for my $x (@{$t->{linux}}) {
-                process_single_test($x, $dir,, $DBNAME, \%res)
-            }
-        }
-    }
-
-    return \%res;
 }
 
+# file: file to be processed. Example: johnson.pg
+# dir: apth of the file. Example: docqueries/allpairs/
+# database: the database name: Example: pgr_test__db__test
+# each tests will use clean data
+
 sub process_single_test{
-    my $x = shift;
+    my $file = shift;
     my $dir = shift;
     my $database = shift;
-    my $res = shift;
-    #each tests will use clean data
 
-    print "Processing queries $dir/$x";
+    (my $filename = $file) =~ s/((\.[^.\s]+)+)$//;
+    my $inputFile = "$dir/$file";
+    my $resultsFile = "$dir/$filename.result";
+
+    print "Processing $inputFile";
     my $t0 = [gettimeofday];
-    #TIN = test_input_file
-    open(TIN, "$dir/$x.test.sql") || do {
-        $res->{"$dir/$x.test.sql"} = "FAILED: could not open '$dir/$x.test.sql' : $!";
+
+    # Load the sample data & any other relevant data files
+    mysystem("$psql $connopts -A -t -q -f tools/testers/sampledata.sql $DBNAME >> $TMP2 2>\&1 ");
+
+    # TIN = test input file
+    open(TIN, "$inputFile") || do {
+        print "\tFAILED: could not open '$inputFile \n";
+        $stats{"$inputFile"} = "FAILED: could not open '$inputFile' : $!";
         $stats{z_fail}++;
-        next;
+        return;
     };
 
-    my $level = "NOTICE";
-    $level = "WARNING" if $ignore;
-    $level = "DEBUG3" if $DEBUG1;
 
+    # Processing is handled kinda like a file
+    # Where the commands are stored on PSQL file
+    # When the PSQL is closed is when everything gets executed
 
+    # Connect to the database with PSQL
     if ($DOCUMENTATION) {
-        open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -e $database > $dir/$x.result 2>\&1 ") || do {
-            $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
+        # For rewriting the results files
+        # Do the rewrite or store FAILURE
+        open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -e $database > $resultsFile 2>\&1 ") || do {
+            $stats{"$inputFile"} = "FAILED: could not open connection to db : $!";
+            $stats{z_fail}++;
             next;
         };
-    }
-    else {
-        #open(PSQL, "|$psql $connopts --set='VERBOSITY terse' -e $database > $dir/$x.result 2>\&1 ") || do {
-        #    $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
-        #    $stats{z_fail}++;
-        #    next;
-        #};
-
+    } else {
+        # For comparing the result
+        # Create temp file with current results
         open(PSQL, "|$psql $connopts  --set='VERBOSITY terse' -e $database > $TMP 2>\&1 ") || do {
-            $res->{"$dir/$x.test.sql"} = "FAILED: could not open connection to db : $!";
-            if (!$INTERNAL_TESTS) {
-               $stats{z_fail}++;
-            }
+            $stats{"$inputFile"} = "FAILED: could not open connection to db : $!";
+            $stats{z_fail}++;
             next;
         };
     }
 
-
-    my @d = ();
-    @d = <TIN>; #reads the whole file into the array @d
+    # Read the whole (input) file into the array @d
+    my @queries = ();
+    @queries = <TIN>;
 
     print PSQL "BEGIN;\n";
-    print PSQL "SET client_min_messages TO $level;\n";
-    #prints the whole fle stored in @d
-    print PSQL @d;
+    print PSQL "SET client_min_messages TO $LEVEL;\n";
+    # prints the whole fle stored in @queries
+    print PSQL @queries;
     print PSQL "\nROLLBACK;";
 
     # executes everything
     close(PSQL);
+
     #closes the input file  /TIN = test input
     close(TIN);
 
+    my $runTime = tv_interval($t0, [gettimeofday]);
+    print "\tRun time: $runTime";
+    $stats{RunTimeTotal} += $runTime;
+
     if ($DOCUMENTATION) {
+        # convert tabs to spaces
         print "\n";
+        my $cmd = q(perl -pi -e 's/[ \t]+$//');
+        $cmd .= " $resultsFile";
+        mysystem( $cmd );
         return;
     }
 
-    my $dfile;
-    my $dfile2;
-    if ($ignore) { #decide how to compare results, if ignoring or not ignoring
-        $dfile2 = $TMP2;
-        mysystem("grep -v NOTICE '$TMP' | grep -v '^CONTEXT:' | grep -v '^PL/pgSQL function' | grep -v '^COPY' > $dfile2");
-        $dfile = $TMP3;
-        mysystem("grep -v NOTICE '$dir/$x.result' | grep -v '^CONTEXT:' | grep -v '^PL/pgSQL function' | grep -v '^COPY' > $dfile");
-    }
-    elsif ($DEBUG1) { #to delete CONTEXT lines
-        $dfile2 = $TMP2;
-        mysystem("grep -v '^CONTEXT:' '$TMP' | grep -v '^PL/pgSQL function' | grep -v '^COPY' > $dfile2");
-        $dfile = $TMP3;
-        mysystem("grep -v '^CONTEXT:' '$dir/$x.result' | grep -v '^PL/pgSQL function' | grep -v '^COPY' > $dfile");
-    }
-    else {
-        $dfile2 = $TMP2;
-        mysystem("grep -v '^COPY' '$TMP' | grep -v 'psql:tools' > $dfile2");
-        $dfile = $TMP3;
-        mysystem("grep -v '^COPY' '$dir/$x.result' | grep -v 'psql:tools' > $dfile");
-    }
-    if (! -f "$dir/$x.result") {
-        $res->{"$dir/$x.test.sql"} = "\nFAILED: result file missing : $!";
+    if (! -f "$resultsFile") {
+        $stats{"$inputFile"} = "\nFAILED: '$resultsFile` file missing : $!";
         $stats{z_fail}++;
         next;
     }
 
-    # use diff -w to ignore white space differences like \r vs \r\n
-    #ignore white spaces when comparing
-    #dfile is expected results
-    #dfile2 is the actual results
-    my $r = `diff -w '$dfile' '$dfile2' `;
+    # diff ignore white spaces when comparing
+    my $originalDiff = `diff -w '$resultsFile' '$TMP' `;
+
     #looks for removing leading blanks and trailing blanks
-    $r =~ s/^\s*|\s*$//g;
-    if ($r =~ /connection to server was lost/) {
-        $res->{"$dir/$x.test.sql"} = "CRASHED SERVER: $r";
+    $originalDiff =~ s/^\s*|\s*$//g;
+    if ($originalDiff =~ /connection to server was lost/) {
+        # when the server crashed
+        $stats{"$inputFile"} = "CRASHED SERVER: $originalDiff";
         $stats{z_crash}++;
         # allow the server some time to recover from the crash
-        warn "CRASHED SERVER: '$dir/$x.test.sql', sleeping 5 ...\n";
+        warn "CRASHED SERVER: '$inputFile', sleeping 5 ...\n";
         sleep 20;
-    }
-    #if the diff has 0 length then everything was the same, so here we detect changes
-    elsif (length($r)) {
-        $res->{"$dir/$x.test.sql"} = "FAILED: $r";
-        $stats{z_fail}++ unless $DEBUG1;
+    } elsif (length($originalDiff)) {
+        # Things changed print the diff
+        $stats{"$inputFile"} = "FAILED: $originalDiff";
+        $stats{z_fail}++ unless $LEVEL ne "NOTICE";
         print "\t FAIL\n";
-    }
-    else {
-        $res->{"$dir/$x.test.sql"} = "Passed";
+    } else {
         $stats{z_pass}++;
         print "\t PASS\n";
     }
-    print "    test run time: " . tv_interval($t0, [gettimeofday]) . "\n";
 }
 
 sub createTestDB {
+    print "-> createTestDB\n" if $VERBOSE;
     my $databaseName = shift;
-    dropTestDB() if dbExists($databaseName);
+    dropTestDB() if $clean && dbExists($databaseName);
 
     my $template;
 
     my $dbver = getServerVersion();
     my $dbshare = getSharePath($dbver);
 
-    if ($DEBUG) {
-        print "-- DBVERSION: $dbver\n";
-        print "-- DBSHARE: $dbshare\n";
+    if ($VERBOSE) {
+        print "\tDBVERSION: $dbver\n";
+        print "\tDBSHARE: $dbshare\n";
     }
 
     die "
     Unsupported postgreSQL version $dbver
     Minimum requierment is $POSGRESQL_MIN_VERSION version
     Use -force to force the tests\n"
-    unless version_greater_eq($dbver, $POSGRESQL_MIN_VERSION) or ($FORCE and version_greater_eq($dbver, '9.1'));
-
-    die "postGIS extension $postgis_ver not found\n"
-    unless -f "$dbshare/extension/postgis.control";
-
+    unless version_greater_eq($dbver, $POSGRESQL_MIN_VERSION);
 
     # Create a database with postgis installed in it
-    mysystem("createdb $connopts $databaseName");
-    die "ERROR: Failed to create database '$databaseName'!\n"
-    unless dbExists($databaseName);
+    mysystem("createdb $connopts $databaseName") if !dbExists($databaseName);
+    die "ERROR: Failed to create database '$databaseName'!\n" unless dbExists($databaseName);
     my $encoding = '';
     if ($OS =~ /msys/
         || $OS =~ /MSWin/) {
         $encoding = "SET client_encoding TO 'UTF8';";
     }
-    print "-- Installing postgis extension $postgis_ver\n" if $DEBUG;
-    mysystem("$psql $connopts -c \"$encoding CREATE EXTENSION postgis $postgis_ver \" $databaseName");
 
     # Install pgrouting into the database
     my $myver = '';
     if ($vpgr) {
         $myver = " VERSION '$vpgr'";
     }
-    print "Installing pgrouting extension $myver\n" if $DEBUG;
-    mysystem("$psql $connopts -c \"CREATE EXTENSION pgrouting $myver\" $databaseName");
+
+
+    mysystem("$psql $connopts -c \"DROP EXTENSION IF EXISTS pgrouting $myver\" $databaseName ");
+
+    print "Installing pgrouting extension $myver\n" if $VERBOSE;
+    mysystem("$psql $connopts -c \"CREATE EXTENSION pgrouting $myver CASCADE\" $databaseName");
 
     # Verify pgrouting was installed
 
     my $pgrv = `$psql $connopts -c "select pgr_version()" $databaseName`;
-    die "ERROR: failed to install pgrouting into the database!\n"
-    unless $pgrv;
+    die "ERROR: failed to install pgrouting into the database!\n" unless $pgrv;
 
-    print `$psql $connopts -c "select version();" postgres `, "\n";
+    print `$psql $connopts -c "select version();" $databaseName `, "\n";
     print `$psql $connopts -c "select postgis_full_version();" $databaseName `, "\n";
     print `$psql $connopts -c "select pgr_full_version();" $databaseName `, "\n";
 }
@@ -501,13 +443,14 @@ sub version_greater_eq {
 
 
 sub getServerVersion {
+    print "-> getServerVersion\n" if $VERBOSE;
     my $v = `$psql $connopts -q -t -c "select version()" postgres`;
-    print "$psql $connopts -q -t -c \"select version()\" postgres\n    # RETURNED: $v\n" if $VERBOSE;
+    print "\t$psql $connopts -q -t -c \"select version()\" postgres\n    # RETURNED: $v\n" if $VERBOSE;
     if ($v =~ m/PostgreSQL (\d+(\.\d+)?)/) {
         my $version = $1 + 0;
-        print "    Got: $version\n" if $VERBOSE;
+        print "\tGot: $version\n" if $VERBOSE;
         $version = int($version) if $version >= 10;
-        print "    Got: $version\n" if $VERBOSE;
+        print "\tGot: $version\n" if $VERBOSE;
         return $version;
     }
     return undef;
@@ -565,17 +508,13 @@ sub getSharePath {
 
 sub mysystem {
     my $cmd = shift;
-    print "$cmd\n" if $VERBOSE || $DRYRUN;
-    system($cmd) unless $DRYRUN;
+    print "$cmd\n" if $VERBOSE;
+    system($cmd);
 }
 
 sub want_tests {
-#    /^bd_d.*\z/s &&
-#    ($File::Find::prune = 1)
-#    ||
     /^test\.conf\z/s &&
     push @cfgs, $name;
-    #print join("\n",@cfgs),"\n";
 }
 
 
